# Examples
This directory contains some useful examples related to the project.

## Table of contents
> - [embedding](#embedding)

## Embedding
Refer to this script to see a minimal basic setup enough to perform the most of tasks with stm32pio projects in your code (i.e. how to establish a core library (`stm32pio` folder) in a 3rd party tools).
